@@ -4,6 +4,7 @@
 #include <QList>
 #include "graphview.h"
 #include "units.h"
+#include "timetype.h"
 
 class Data;
 class PathItem;
@@ -18,10 +19,11 @@ public:
 
 	virtual QString label() const = 0;
 	virtual void loadData(const Data &data, const QList<PathItem *> &paths) = 0;
-	virtual void clear() = 0;
-	virtual void setUnits(enum Units units) = 0;
-	virtual void showTracks(bool show) = 0;
-	virtual void showRoutes(bool show) = 0;
+	virtual void clear() {}
+	virtual void setUnits(enum Units units) {Q_UNUSED(units)}
+	virtual void setTimeType(enum TimeType type) {Q_UNUSED(type)}
+	virtual void showTracks(bool show) {Q_UNUSED(show)}
+	virtual void showRoutes(bool show) {Q_UNUSED(show)}
 };
 
 #endif // GRAPHTAB_H
