@@ -3,7 +3,6 @@
 #include <QMouseEvent>
 #include <QPaintEngine>
 #include <QPaintDevice>
-#include <QSysInfo>
 #include "opengl.h"
 #include "config.h"
 #include "axisitem.h"
@@ -25,6 +24,7 @@ GraphView::GraphView(QWidget *parent)
 	_scene = new QGraphicsScene(this);
 	setScene(_scene);
 
+	//setBackgroundBrush(QBrush(Qt::white));
 	setViewportUpdateMode(QGraphicsView::FullViewportUpdate);
 	setRenderHint(QPainter::Antialiasing, true);
 	setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -56,7 +56,7 @@ GraphView::GraphView(QWidget *parent)
 	_sliderPos = 0;
 
 	_units = Metric;
-    _graphType = gtDistance;
+	_graphType = gtDistance;
 	_xLabel = tr("Distance");
 }
 
@@ -102,7 +102,7 @@ void GraphView::setYUnits(const QString &units)
 
 void GraphView::setXUnits()
 {
-    if (_graphType == gtDistance) {
+	if (_graphType == gtDistance) {
 		if (_units == Metric) {
 			if (bounds().width() < KMINM) {
 				_xUnits = tr("m");
@@ -121,7 +121,7 @@ void GraphView::setXUnits()
 			}
 		}
 	} else {
-		    if (bounds().width() < MININS) {
+			if (bounds().width() < MININS) {
 				_xUnits = tr("s");
 				_xScale = 1;
 			} else if (bounds().width() < HINS) {
@@ -153,7 +153,7 @@ void GraphView::setGraphType(GraphType type)
 			_bounds |= _graphs.at(i)->bounds();
 	}
 
-    if (type == gtDistance)
+	if (type == gtDistance)
 		_xLabel = tr("Distance");
 	else
 		_xLabel = tr("Time");
@@ -458,11 +458,8 @@ void GraphView::setGraphWidth(int width)
 
 void GraphView::useOpenGL(bool use)
 {
-	if (use) {
-#ifdef Q_OS_WIN32
-		if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA)
-#endif // Q_OS_WIN32
+	if (use)
 		setViewport(new OPENGL_WIDGET);
-	} else
+	else
 		setViewport(new QWidget);
 }
