@@ -1,8 +1,6 @@
 #include <QGraphicsView>
 #include <QGraphicsScene>
 #include <QWheelEvent>
-#include <QSysInfo>
-#include <QDebug>
 #include "opengl.h"
 #include "rd.h"
 #include "wgs84.h"
@@ -286,7 +284,7 @@ QPointF PathView::contentsCenter() const
 void PathView::updatePOIVisibility()
 {
 	QHash<Waypoint, WaypointItem*>::const_iterator it, jt;
-    qDebug()<<"updatevis" << _showPOI;
+
 	if (!_showPOI)
 		return;
 
@@ -353,7 +351,6 @@ void PathView::setPOI(POI *poi)
 
 void PathView::updatePOI()
 {
-    qDebug() << "update poi";
 	QHash<Waypoint, WaypointItem*>::const_iterator it;
 
 	for (it = _pois.constBegin(); it != _pois.constEnd(); it++) {
@@ -376,8 +373,7 @@ void PathView::updatePOI()
 
 void PathView::addPOI(const QVector<Waypoint> &waypoints)
 {
-    qDebug()<<"add Poi " << waypoints.size();
-    qreal scale = mapScale(_zoom);
+	qreal scale = mapScale(_zoom);
 
 	for (int i = 0; i < waypoints.size(); i++) {
 		const Waypoint &w = waypoints.at(i);
@@ -391,7 +387,7 @@ void PathView::addPOI(const QVector<Waypoint> &waypoints)
 		pi->showLabel(_showPOILabels);
 		pi->setVisible(_showPOI);
 		_scene->addItem(pi);
-        qDebug()<< "pi" << pi << scale;
+
 		_pois.insert(w, pi);
 	}
 }
@@ -451,7 +447,6 @@ void PathView::zoom(int z, const QPoint &pos)
 	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
 	_mapScale->setResolution(_res);
 
-
 	resetCachedContent();
 }
 
@@ -476,18 +471,17 @@ void PathView::mouseDoubleClickEvent(QMouseEvent *event)
 #ifdef Q_WS_MAEMO_5
 void PathView::mousePressEvent(QMouseEvent *e)
 {
-    if (e->button() == Qt::RightButton)
-        QWidget::mousePressEvent(e);
-    else
-        QGraphicsView::mousePressEvent(e);
+	if (e->button() == Qt::RightButton)
+		QWidget::mousePressEvent(e);
+	else
+		QGraphicsView::mousePressEvent(e);
 }
 void PathView::zoom_maemo(QString direction)
 {
-    qDebug()<< "zoomm" << direction;
-    int z = -1;
-    if (direction=="in") z = qMin(_zoom + 1, ZOOM_MAX);
-    else z = qMax(_zoom - 1, ZOOM_MIN);
-    if (z >= 0) zoom(z, QRect(QPoint(), size()).center());
+	int z = -1;
+	if (direction=="in") z = qMin(_zoom + 1, ZOOM_MAX);
+	else z = qMax(_zoom - 1, ZOOM_MIN);
+	if (z >= 0) zoom(z, QRect(QPoint(), size()).center());
 }
 #endif
 
@@ -496,13 +490,13 @@ void PathView::keyPressEvent(QKeyEvent *event)
 	int z = -1;
 
 #ifdef Q_WS_MAEMO_5
-    if (event->key()==Qt::Key_F7)
-        z = qMin(_zoom + 1, ZOOM_MAX);
-    else if (event->key()==Qt::Key_F8)
-        z = qMax(_zoom - 1, ZOOM_MIN);
-    else QWidget::keyPressEvent(event);
-    if (z >= 0)
-        zoom(z, QRect(QPoint(), size()).center());
+	if (event->key()==Qt::Key_F7)
+		z = qMin(_zoom + 1, ZOOM_MAX);
+	else if (event->key()==Qt::Key_F8)
+		z = qMax(_zoom - 1, ZOOM_MIN);
+	else QWidget::keyPressEvent(event);
+	if (z >= 0)
+		zoom(z, QRect(QPoint(), size()).center());
 #else
 	if (event->matches(QKeySequence::ZoomIn))
 		z = qMin(_zoom + 1, ZOOM_MAX);
@@ -723,7 +717,6 @@ void PathView::resizeEvent(QResizeEvent *event)
 	_res = zoom2resolution(_zoom, -(center.y() * mapScale(_zoom)));
 	_mapScale->setResolution(_res);
 
-
 	resetCachedContent();
 }
 
@@ -753,11 +746,8 @@ void PathView::scrollContentsBy(int dx, int dy)
 
 void PathView::useOpenGL(bool use)
 {
-	if (use) {
-#ifdef Q_OS_WIN32
-		if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA)
-#endif // Q_OS_WIN32
+	if (use)
 		setViewport(new OPENGL_WIDGET);
-	} else
+	else
 		setViewport(new QWidget);
 }
