@@ -13,9 +13,7 @@ public:
 	QString label() const {return tr("Power");}
 	void loadData(const Data &data, const QList<PathItem *> &paths);
 	void clear();
-	void setUnits(enum Units) {}
 	void showTracks(bool show);
-	void showRoutes(bool show) {Q_UNUSED(show);}
 
 private:
 	qreal avg() const;
